;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x3d842d91d8d242f1b02113e4bdfa4155 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#xdf730cc427faa4da5280fca787f9be2f . "./code.cg2js/cg-drag-and-drop.fasl")
(#xa710fb71a08a2e183acc84416c96fd1c . "./code.cg2js/cg-toolbar.fasl")
(#x5ecfa60197dc9d239c9f7cf97b710712 . "./code.cg2js/cg-chart-or-plot.fasl")
(#x47216e81ac70a9f46187e3c0bb3d40be . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x1af88a3998d3c032e10e8f88d80515e2 . "./code.cg2js/cg-class-grid.fasl")
(#xbf975c0d8fc08ef8e6a4b69a6d021656 . "./code.cg2js/cg-tray.fasl")
(#x219c065e33090242c5b44f53eea052f9 . "./code.cg2js/cg-gesture-emulation.fasl")
(#xfaaf7c87885abcc070e8db67d6f0a1ab . "./code.cg2js/cg-class-support.fasl")
(#xc9bf9b132d10f246f63611ec6f52b2bd . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#xa71b762eda037ea87560d46173fb0ff6 . "./code.cg2js/cg-dropping-outline.fasl")
(#x93ed8a575e1c5fd14b4a419347ce77b1 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x4aaea28e2dcf94241d0ce5ead25a4966 . "./code.cg2js/cg-choice-list.fasl")
(#x98a0151a0b62a52d557d093b1520e54d . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#x42efe7fc6f7f4cb2ff6f2677886b4962 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x4cc3da9e8d586192cab841600ab4e86d . "./code.cg2js/cg-timer.fasl")
(#x87dea5e26f810143a42e7cec51e9f196 . "./code.cg2js/cg-directory-dialog.fasl")
(#x9df3aeafa0ebb665c537433831036828 . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#xeec7b77ea9c440c14c629b88b903fc04 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x219476d94341c7cee5f68612a9d56802 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x24eb5f4d05818f55ed1be97e331769b8 . "./code.cg2js/cg-html-widget.fasl")
(#x15bcbe49308e6022be2889640662c343 . "./code.cg2js/cg-selected-object.fasl")
(#x17b17aab29d0cbb44d10de9477e471bc . "./code.cg2js/cg-lamp.fasl")
(#x67ef0d3cff426e82742d026dcd246160 . "./code.cg2js/cg-scroll-bar.fasl")
(#x69c9e9ef9356145b9bc97863c4320f7b . "./code.cg2js/cg-cursor-pixmap.fasl")
(#x808fa8a3fa04fda4786c2ac30fc53919 . "./code.cg2js/cg-message-dialog.fasl")
(#xae387dd959ef4dc78f2d370b9c7de72d . "./code.cg2js/cg-dde-utils.fasl")
(#x6768a8e6c0404b122b6f237cc80d79f8 . "./code.cg2js/cg-group-box.fasl")
(#xbba681c4a7278090d4c68c578d7c2cb5 . "./code.cg2js/cg-find-string-dialog.fasl")
(#x2e90887f92b30ace2c096ade0b54859b . "./code.cg2js/cg-split-bar.fasl")
(#xbece1ad46fa389d40530ca72d51cdf0b . "./code.cg2js/cg-radio-button.fasl")
(#xb3917b39bb5cd4903b4c102ec3ad68f5 . "./code.cg2js/cg-base.fasl")
(#x08c73bc2b979bb4c5b7e3b866013778c . "./code.cg2js/cg-paren-matching.fasl")
(#x1092d4f6c1df4feeef8ac4a94daaa576 . "./code.cg2js/cg-graphics-context.fasl")
(#x54dcfe0a79ae0cab6bf94db6a434432c . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#xa4bf1cb22a2cbe03486afec6778fc2e0 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x39ab0d5abea17242e048247631ae92b8 . "./code.cg2js/cg-plot-widget.fasl")
(#x2ede184978577fdc5a6f700ce4fcc23d . "./code.cg2js/cg-dev.fasl")
(#x845845289b346964187b063b4370db84 . "./code.cg2js/cg-text-edit-pane.fasl")
(#xf999f7ea8dc7612fdb9021b68611af83 . "./code.cg2js/cg-tab-control.fasl")
(#x6a9fada0ee03e07f08abb2acf1e13935 . "./code.cg2js/cg-fill-texture.fasl")
(#x6a1c06a350355a886f74de9094346404 . "./code.cg2js/cg-menu-tooltip.fasl")
(#x8b73e71f5c6224aea789250a4fcb2901 . "./code.cg2js/cg-trackbar.fasl")
(#xcab78fd6699407215c688ba2e43673f0 . "./code.cg2js/cg-nodes.fasl")
(#xeb7d06641dcc4bf9a9d50e8c091453b2 . "./code.cg2js/cg-common-control.fasl")
(#x81bdd3b9a6c829f20349054d44491863 . "./code.cg2js/cg-list-view.fasl")
(#x990b3213ae6e77cd3eaf5c0996fbcf1f . "./code.cg2js/cg-rich-edit.fasl")
(#xdd9415157f45a2e02fa64313792d97bc . "./code.cg2js/cg-project-window.fasl")
(#xa41c24d46563749cbe698d46bbb63b89 . "./code.cg2js/cg-item-list.fasl")
(#x1d8749eb6c52e40872dd2db788285e7e . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#xcb46a6fb17ff4285c983ec83a38318fa . "./code.cg2js/cg-get-position.fasl")
(#x686d0baf7acf229c9ee017695e51c57a . "./code.cg2js/cg-bitmap-pane.fasl")
(#x6d313938a63ceca89324b6fe1b56f0e8 . "./code.cg2js/cg-drawable.fasl")
(#x679ba12b6ad8acb84cb8a0d8cacdfa57 . "./code.cg2js/cg-lettered-menu.fasl")
(#xa44c8ab5aa434c2a12b7da06416c8564 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x6e885e0657ba914a690e24dd81398575 . "./code.cg2js/cg-html-dialog.fasl")
(#xee98d2dcda4019961e62be7a9c19968f . "./code.cg2js/cg-object-editor-layout.fasl")
(#x79194a68a3dae4c5e35ee58f8c3b8615 . "./code.cg2js/cg-utility-dialog.fasl")
(#xc2e90916326d5eafa03fcd64dadce23f . "./code.cg2js/cg-pixmap-widget.fasl")
(#xca38b8da44a4ea5f4991dedff17b6ff3 . "./code.cg2js/cg-property.fasl")
(#x0fee078419820ba3fa575a01db709533 . "./code.cg2js/cg-menu.fasl")
(#x71aee706de9b39bbb73d54bf413fb426 . "./code.cg2js/cg-clipboard.fasl")
(#xc657759c05ddd52c65ede7fc10489de3 . "./code.cg2js/cg-toggling-widget.fasl")
(#xde27b1aef4ae3442dfa8856266a5fb2b . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x40f112b949559697c22454cb7f3088d5 . "./code.cg2js/cg-template-string.fasl")
(#xafb9667879a1ae0fdd0882941b77fb37 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x9adfe67f475e9cefa299404d12b9774e . "./code.cg2js/cg-os-window.fasl")
(#xe7a15f139b64b0d8c80b8d0d71d6ec56 . "./code.cg2js/cg-grid-widget.fasl")
(#x0d516789261b0dbea5e6262c5f9eeb8b . "./code.cg2js/cg-picture-widget.fasl")
(#xf386f1783d50bd1b21d2dadc77d3a661 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x5ee77e945107cfeea9045bf39bc88a56 . "./code.cg2js/cg-static-text.fasl")
(#x33b9dc9a134518140d44cbfb5df5847a . "./code.cg2js/cg-clipboard-stack.fasl")
(#x9084f1459243ad1129c6204c196ed873 . "./code.cg2js/cg-text-widget.fasl")
(#xc942c0b7a1480643dee5ba712b8a42e3 . "./code.cg2js/cg-calendar.fasl")
(#x30f6042530e2b0d969ae7a99abf49622 . "./code.cg2js/cg-check-box.fasl")
(#x4eebed9ac2c5323497fae652cf33d474 . "./code.cg2js/cg-acache.fasl")
(#xb6771a99fc58006b010b9395f29877fd . "./code.cg2js/cg-wrap-string.fasl")
(#x2c7b1a6437b9f84c71993fe89dcb61de . "./code.cg2js/cg-bitmap-stream.fasl")
(#xbf211d91912473f41c9ab8ddbc3fb404 . "./code.cg2js/cg-font-dialog.fasl")
(#x3d300046c118107e0acc37a495732eed . "./code.cg2js/cg-outline.fasl")
(#x0ce149be52a114e6d721ecd0d1aca125 . "./code.cg2js/cg-shortcut-menu.fasl")
(#x66f7b45001d69bce4716d4ad1cdf0db0 . "./code.cg2js/cg-status-bar.fasl")
(#xfd02bf62f2e568b3d1b9426be39aff62 . "./code.cg2js/cg-multi-picture-button.fasl")
(#x91fbb3b6117f34327ad167c5815250c1 . "./code.cg2js/cg-hotspot.fasl")
(#x68ff116e10efc1ddb04d2da0a05047b7 . "./code.cg2js/cg-scaling-stream.fasl")
(#x94600f7cb3300601f4b1fb97c4e30323 . "./code.cg2js/cg-icon-pixmap.fasl")
(#x225266fd30f61b137bdea6d957b368de . "./code.cg2js/cg-file-dialog.fasl")
(#xfb635b9fd0584ce133c0cb502dbd0e2a . "./code.cg2js/cg-color-dialog.fasl")
(#x5bf46951f1e96443afb4187394f8ab51 . "./code.cg2js/cg-get-pixmap.fasl")
(#x2a8ded3ee929cb310a57dbe639db8651 . "./code.cg2js/cg-object-editor.fasl")
(#x533e6a14346e4feaf37656f0497cb0e9 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x31a3fb62d6bf8683cd19253c77c91c10 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#xab434f767faee141c6c8eb1659ce0226 . "./code.cg2js/cg-pixmap.fasl")
(#xe95ae8597cfedbb26be398bae2229a30 . "./code.cg2js/cg-intersect.fasl")
(#xb2246ebb706828709a3bccb82076504d . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x1869be93ba7bf0c8b8374153c846fa49 . "./code.cg2js/cg-icon.fasl")
(#xb09361689a3a53b18cbf42dae4402fb7 . "./code.cg2js/cg-yes-no-string.fasl")
(#x120b1ad8747262c157fcf0ca488972de . "./code.cg2js/cg-text-or-combo.fasl")
(#x01e995de97feed4bbd1a966b40ba304f . "./code.cg2js/cg.fasl")
(#xf04c1ccc5c08f3f1fdafb19a99f5566d . "./code.cg2js/cg-dialog-item.fasl")
(#xfa0881f78337919c4e07970606ee00bb . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x794495d0d2b8946dfdc6b0e601985ac7 . "./code.cg2js/cg-caret.fasl")
(#xda30e012fa0302afba4322cdb140ef1d . "./code.cg2js/cg-editable-text.fasl")
(#xc663484b95a0810fbc8977911b5feb03 . "./code.cg2js/cg-choose-printer.fasl")
(#xdd2f42479194930ff3aaf6846e975fa4 . "./code.cg2js/cg-yes-no-list.fasl")
(#x9b896836f88036bcbefde88f1a9a36a1 . "./code.cg2js/cg-intersect-posbox.fasl")
(#xa65b4792ce1641f2dd3149a8b5ab65e1 . "./code.cg2js/cg-tooltip.fasl")
(#x02d26fa51096f063e0cdafac74100218 . "./code.cg2js/cg-class-slot-grid.fasl")
(#xe254fd7a1f1cb88407e03fdbc05f47b3 . "./code.cg2js/cg-combo-box.fasl")
(#x0d3e5e672cb87c1a87c75e80bd7cfeca . "./code.cg2js/cg-curve.fasl")
(#x1310429a1ebdd6f981a39dc91122152c . "./code.cg2js/cg-web-browser.fasl")
(#x4ffdd4479395325a9eb0fe1a818ff3e8 . "./code.cg2js/cg-printing.fasl")
(#x050c8b092abc0a428b8cb8b7ab24ccea . "./code.cg2js/cg-lisp-widget.fasl")
(#xb4c144802029d26a09f725523e52ea3e . "./code.cg2js/cg-sample-file-menu.fasl")
(#x0aa5c37d2d762f752b2fc230cd4f0387 . "./code.cg2js/cg-palette.fasl")
(#xf9358d2a59fb03086ce0a673520febee . "./code.cg2js/cg-os-widget.fasl")
(#xbc5d0cfa4fa6de7fe764fcc899c6e816 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x6ac67813b7921b2023c0ea69b261ebe8 . "./code.cg2js/cg-pixmap-printing.fasl")
(#xf722ca39dd61fe54fa945fb94c0d9b09 . "./code.cg2js/cg-button.fasl")
(#x7c5a6b82f21e3e293e647068f4e36594 . "./code.cg2js/cg-edit-in-place.fasl")
(#xf8711b28ca7575e6c2a3371fea1dd4bd . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#xf17caccbe98b472ea32328355c18f6ce . "./code.cg2js/cg-comtab.fasl")
(#xe074e7b4bb3bb66d6dfd334e1cd9d23e . "./code.cg2js/cg-string-dialog.fasl")
(#xfab2b5f5712b516c3745d3806b718dd0 . "./code.cg2js/cg-header-control.fasl")
(#x69a5cad978f4b7955214c75d27736d25 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#xb2b263e2f62ec9c82409cb562aa8468c . "./code.cg2js/cg-up-down-control.fasl")
(#x678e3e8028f5a55554bfa9bd0bdbb2b4 . "./code.cg2js/cg-layout.fasl")
(#x37860cdc0652092e5ba26277f7328855 . "./code.cg2js/cg-chart-widget.fasl")
(#xaa6b8d2caa2fc2e14a57f07971c9b64d . "./code.cg2js/cg-lisp-text.fasl")
(#x13ee1a78f94d3adaa9450100f05736b6 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x065d50a315779aaa6c26152fbc0b0fde . "./code.cg2js/cg-progress-indicator.fasl")
(#x7852897e6cf0898b1b0b64ed1faec8c7 . "./code.idejs/ide-inspector.fasl")
(#x1698a8bf59bafe44399246df79260514 . "./code.idejs/ide-grapher.fasl")
(#x2fc3a6e44eb42ba718b4112def99d263 . "./code.idejs/ide-base.fasl")
(#xb04b2709c72c3cd56dba1300d046aa10 . "./code.idejs/ide-keyshort.fasl")
(#x158cf643f4780a57df858131d0a50e83 . "./code.idejs/ide-dev.fasl")
(#x8fcdc7d41acf3325efc13b304c8c448a . "./code.idejs/ide-class-browser.fasl")
(#x127cad20cbe3f934172ccacb37e53387 . "./code.idejs/ide-package-list.fasl")
(#x6824c0d4d407684d3c055001881da9c8 . "./code.idejs/ide-intro.fasl")
(#x247f07c8c2581c663b1305bf0c361be4 . "./code.idejs/ide-class-grapher.fasl")
(#xa79d6e04ce6c97913b09a03c250489c4 . "./code.idejs/ide-window-list.fasl")
(#xfb1e4dd07f5ff0234c31fca43d003213 . "./code.idejs/ide-find-definitions.fasl")
(#x5bc9666f744aafe9b41b47f289ac4e22 . "./code.idejs/ide-trace.fasl")
(#x1d818b510a8976101a8b711de7f7ce65 . "./code.idejs/ide-editor.fasl")
(#x9689f06bb0a9b1c2f67b779c35bb5a86 . "./code.idejs/ide-patch-dialog.fasl")
(#x91ecaf52f0a073352f55cfb65c57a731 . "./code.idejs/ide-project.fasl")
(#x45c9813c6fc6c1d9ff2e2ff1a4fc885f . "./code.idejs/ide.fasl")
(#x13c911d6430b829c27ca4ceae924c184 . "./code.idejs/ide-apropos.fasl")
(#xc2f86bea4f3fd703d2bb605d473f86ba . "./code.idejs/ide-acache.fasl")
(#xed281ceba7e895c80e344510f7005e65 . "./code.idejs/ide-clipboard.fasl")
(#xc5cde6563cb7f660452cac9274a0b18a . "./code.idejs/ide-process-browser.fasl")
(#x6635434eb40e615c243f736b9367c457 . "./code.idejs/ide-find-in-files.fasl")
(#x9556038669a6faf3a0f3fb3a8289d252 . "./code.idejs/ide-form.fasl")
(#x173984e2342893e68185356ce7e59b9a . "./code.idejs/ide-navigator.fasl")
(#xe396744af4d34e05e734175c54f8cafc . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
